/**
 * Generate theme stylesheet.
 * @memberof module:apiguide/lib
 * @function _generateTheme
 * @param {string} dirname - Destination directory name.
 * @param {object} data - Theme data.
 * @param {function} callback - Callback when done.
 */

"use strict";

var coz = require('coz'),
    argx = require('argx'),
    fs = require('fs'),
    path = require('path');

var PRIMARY_COLOR = '#418300';

/** @lends _generateTheme */
function _generateTheme(dirname, data, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    data = args.pop('object') || {};
    coz.render({
        force: true,
        mkdirp: true,
        path: path.resolve(dirname, 'styles/site.dynamic.css'),
        get tmpl() {
            var tmpl = fs.readFileSync(path.resolve(__dirname, '../assets/theme/theme.css'));
            return String(tmpl).replace(new RegExp(PRIMARY_COLOR, 'g'), data.color || '#38E');
        },
        data: data
    }, callback);
}

module.exports = _generateTheme;
